@@ -1,16 +1,8 @@
-"""spymetadata - Python utilities for metadata."""
+"""pymetadata - Python utilities for metadata."""
 from pathlib import Path
 
 __author__ = "Matthias Koenig"
-__version__ = "0.2.6"
-
-
-from depinfo import print_dependencies  # type: ignore
-
-
-def show_versions() -> None:
-    """Print dependency information."""
-    print_dependencies("pymetadata")
+__version__ = "0.3.0"
 
 
 program_name: str = "pymetadata"
