@@ -272,6 +272,7 @@ class EntryFormat(str, Enum):
     XOF = PURL_PREFIX + "x-world/x-vrml"
     XPM = PURL_PREFIX + "image/x-xpixmap"
     XWD = PURL_PREFIX + "image/x-xwindowdump"
+    YAML = PURL_PREFIX + "text/yaml"
     Z = PURL_PREFIX + "application/x-compress"
     ZIP = PURL_PREFIX + "application/zip"
 
@@ -347,6 +348,7 @@ class Manifest(BaseModel):
     ]
 
     def __init__(self, **data) -> None:  # type: ignore
+        """Initialize Manifest."""
         super().__init__(**data)
         for e in self.entries:
             if not e.location.startswith("."):
@@ -389,7 +391,7 @@ class Manifest(BaseModel):
             if e.master:
                 master_token = ' master="true"'
             else:
-                master_token = ""
+                master_token = ' master="false"'
             return f'  <content location="{e.location}" format="{e.format}"{master_token} />'
 
         lines = (
@@ -413,17 +415,14 @@ class Manifest(BaseModel):
 
         Does not check for duplication.
         """
-        if not entry.location.startswith("./"):
-            raise ValueError(
-                f"Locations must be relative paths in COMBINE archive, but location is "
-                f"'{entry.location}'."
-            )
-
+        entry.location = self._check_and_normalize_location(entry.location)
         self.entries.append(entry)
         self._entries_dict[entry.location] = entry
 
     def remove_entry_for_location(self, location: str) -> Optional[ManifestEntry]:
         """Remove entry for given location."""
+        location = self._check_and_normalize_location(location)
+
         if location in [".", "./manifest.xml"]:
             logger.error(
                 f"Core location cannot be removed from manifest: '{location}'."
@@ -437,6 +436,21 @@ class Manifest(BaseModel):
             self.entries = [e for e in self.entries if e.location != location]
             return entry
 
+    @staticmethod
+    def _check_and_normalize_location(location: str) -> str:
+        """Add relative prefix and check location."""
+
+        if location.startswith("/"):
+            raise ValueError(
+                f"Locations must be relative paths in COMBINE archive, but location is "
+                f"'{location}'."
+            )
+
+        # add prefix
+        if not location.startswith("./") and location != ".":
+            location = f"./{location}"
+        return location
+
 
 class Omex:
     """Combine archive class."""
@@ -738,14 +752,21 @@ class Omex:
         extension = path.suffix[1:] if path.suffix else ""
         if extension == "xml":
             with open(path, "r") as f_in:
-                text = f_in.read(256)
-                if "<sbml" in text:
-                    return Omex.lookup_format("sbml")
-                if "<sedML" in text:
-                    return Omex.lookup_format("sedml")
-                if "<cell" in text:
-                    return Omex.lookup_format("cellml")
-                if "<COPASI" in text:
-                    return Omex.lookup_format("copasi")
+                try:
+                    text = f_in.read(256)
+                    if "<sbml" in text:
+                        return Omex.lookup_format("sbml")
+                    if "<sedML" in text:
+                        return Omex.lookup_format("sedml")
+                    if "<cell" in text:
+                        return Omex.lookup_format("cellml")
+                    if "<COPASI" in text:
+                        return Omex.lookup_format("copasi")
+                except UnicodeDecodeError as err:
+                    # handle incorrect encodings
+                    logger.error(
+                        f"UnicodeDecodeError in '{path}', "
+                        f"incorrect file encoding: '{err}'"
+                    )
 
         return Omex.lookup_format(extension)
